Protein Interaction Network inFERence (PINFER).
===============================

Currently this represents a pure Python reimplementation of the approach found in Pinney et al. 2007. Full explanation of the approach can be found in the original paper, and (in time) in examples here.

Reconstruction of ancestral protein interaction networks for the bZIP transcription factors.
Pinney, J. W., Amoutzias, G. D., Rattray, M., & Robertson, D. L. (2007).
Proc Natl Acad Sci U S A, 104(51), 20449–20453.
[http://doi.org/10.1073/pnas.0706339104](http://doi.org/10.1073/pnas.0706339104)

###  Warning : This module is still very much under development!

In the (nearish) future it will include useful things such as...

* (more) unit testing
* example Jupyter notebooks
* novel functionality to enable more flexible inference of protein interaction histories

When possible, advances on the original approach will be made available here.
